// import 'source-map-support/register';
import { WyWallBacklistPluginConfig } from './config';
import {
  CommandExample,
  CommandLocale,
  CRenderer,
  DefinePlugin,
  Inject,
  InjectLogger,
  PutArg,
  PutCommonRenderer,
  StarterPlugin,
  UseCommand,
} from 'koishi-thirdeye';
import { Logger, Quester } from 'koishi';
import { BlacklistReturn } from './types';
export * from './config';

@DefinePlugin({ name: 'wyblacklist' })
export default class WyWallBacklistPlugin extends StarterPlugin(
  WyWallBacklistPluginConfig,
) {
  @Inject(true)
  private http: Quester;

  @InjectLogger()
  private logger: Logger;

  @UseCommand('wybl <account:posint>')
  @CommandExample('wybl 123456789')
  @CommandLocale('zh', {
    description: '蔷蔷挂人查询',
    messages: {
      fail: '查询失败。',
      safe: '用户 {account} 是安全的。',
      unsafe: '用户 {account} 存在风险。',
      invalid: '请输入正确的 QQ 号。',
    },
  })
  @CommandLocale('en', {
    description: 'Query the blacklist of Wenyuan Wall.',
    messages: {
      fail: 'Failed to query blacklist.',
      safe: 'User {account} is safe.',
      unsafe: 'User {account} is risky.',
      invalid: 'Please input a valid QQ number.',
    },
  })
  async wybl(@PutArg(0) account: number, @PutCommonRenderer() r: CRenderer) {
    if (account < 10000 || account > 9999999999) {
      return r('.invalid', { account });
    }

    try {
      const result = await this.http.get<BlacklistReturn>(
        `${this.config.endpoint}/api/blacklist`,
        {
          responseType: 'json',
          params: {
            recordsPerPage: 100,
            account,
          },
        },
      );
      if (!result.data.length) {
        return r('.safe', { account });
      }
      return [
        r('.unsafe', { account }),
        '',
        ...result.data.map(
          (item) =>
            `${new Date(item.blacklist.time).toLocaleString()} ${
              item.blacklist.content
            }`,
        ),
      ].join('\n');
    } catch (e) {
      this.logger.error(`Failed to fetch blacklist of ${account}: ${e}`);
      return r('.fail');
    }
  }
}
